@@ -22,7 +22,7 @@ class AutoFeat(object):
     def __init__(self, df, entity_id, type2features, index=None, time_index=None, secondary_time_index=None):
         self.entity_id = entity_id  # 表名
         self.type2features = type2features
-        self.index = '__id' if index is None else index # 索引列不能当target_entity
+        self.index = '__id' if index is None else index  # 索引列不能当target_entity
 
         self.es = ft.EntitySet(id='MAIN')
         self.es.entity_from_dataframe(
@@ -47,7 +47,7 @@ class AutoFeat(object):
     def run_dfs(self, es, target_entity, max_depth, chunk_size, n_jobs, features_only, ignore_variables):
         _ = ft.dfs(
             entityset=es,
-            target_entity=target_entity,
+            target_entity=target_entity,  # 具有唯一ID
             max_depth=max_depth,
             verbose=1,
             chunk_size=chunk_size,
@@ -81,3 +81,18 @@ class AutoFeat(object):
     @property
     def vt(self):
         return vt
+
+
+if __name__ == '__main__':
+    import pandas as pd
+
+    df = pd.DataFrame([[1, 2, 3], [2, 2, 3], [3, 2, 3]], columns=['uid', 'a', 'b'])
+
+    type2features = {
+        vt.Id: ['uid'],
+        vt.Categorical: ['a', 'b']
+    }
+
+    af = AutoFeat(df, 'test', type2features)
+    af.dfs('uid')
+    af.es.plot()
